package com.inspect.metadata.montdata.service;

import com.inspect.metadata.montdata.domain.BasedataMontPatDevPatRoute;
import com.inspect.metadata.montdatamqhandle.vo.CoordAndRoute;

import java.util.List;

public interface IBasedataMontPatDevPatRouteService {
    BasedataMontPatDevPatRoute selectBasedataMontPatDevPatRouteByMontPatDevRouteId(Long routeId);

    List<BasedataMontPatDevPatRoute> selectBasedataMontPatDevPatRouteList(BasedataMontPatDevPatRoute patRoute);

    int insertBasedataMontPatDevPatRoute(BasedataMontPatDevPatRoute patRoute);

    int updateBasedataMontPatDevPatRoute(BasedataMontPatDevPatRoute patRoute);

    int deleteBasedataMontPatDevPatRouteByMontPatDevPatRouteIds(Long[] routeIds);

    int deleteBasedataMontPatDevPatRouteByMontPatDevPatRouteId(Long routeId);

    CoordAndRoute queryCoordAndRouteList(String key);
}
